@@ -19,7 +19,7 @@
 #' @param method one of "modified","gaussian","historical", see
 #' Details.
 #' @param clean method for data cleaning through \code{\link{Return.clean}}.
-#' Current options are "none", "boudt", or "geltner".
+#' Current options are "none", "boudt", "geltner", or "locScaleRob".
 #' @param portfolio_method one of "single","component","marginal" defining
 #' whether to do univariate, component, or marginal calc, see Details.
 #' @param weights portfolio weighting vector, default NULL, see Details
@@ -37,6 +37,8 @@
 #' @param invert TRUE/FALSE whether to invert the VaR measure, see Details.
 #' @param operational TRUE/FALSE, default TRUE, see Details.
 #' @param \dots any other passthru parameters
+#' @param SE TRUE/FALSE whether to ouput the standard errors of the estimates of the risk measures, default FALSE.
+#' @param SE.control Control parameters for the computation of standard errors. Should be done using the \code{\link{RPESE.control}} function.
 #' @note The option to \code{invert} the ES measure should appease both
 #' academics and practitioners.  The mathematical definition of ES as the
 #' negative value of extreme losses will (usually) produce a positive number.
@@ -118,7 +120,7 @@
 #' Operational = TRUE to replace modified ES with modified VaR in the
 #' (exceptional) case where the modified ES is smaller than modified VaR.
 #' 
-#' @section Component ES
+#' @section Component ES:
 #' 
 #' By setting \code{portfolio_method="component"} you may calculate the ES
 #' contribution of each element of the portfolio. The return from the function in
@@ -212,6 +214,9 @@
 ###keywords ts multivariate distribution models
 #' @examples
 #' 
+#' if(!( Sys.info()[['sysname']]=="Windows") ){
+#' # if on Windows, cut and paste this example
+#' 
 #'     data(edhec)
 #' 
 #'     # first do normal ES calc
@@ -233,19 +238,38 @@
 #' 
 #'     # add Component ES for the equal weighted portfolio
 #'     ES(edhec, clean="boudt", portfolio_method="component")
+#' 
+#' } # end CRAN Windows check
 #'     
 #' @export ETL CVaR ES
 ETL <- CVaR <- ES <- function (R=NULL , p=0.95, ..., 
         method=c("modified","gaussian","historical"), 
-        clean=c("none","boudt", "geltner"),  
+        clean=c("none","boudt", "geltner", "locScaleRob"),  
         portfolio_method=c("single","component"), 
         weights=NULL, mu=NULL, sigma=NULL, m3=NULL, m4=NULL, 
-        invert=TRUE, operational=TRUE)
+        invert=TRUE, operational=TRUE,
+        SE=FALSE, SE.control=NULL)
 { # @author Brian G. Peterson
 
     # Descripion:
 
     # wrapper for univariate and multivariate ES functions.
+  
+    # Fix parameters if SE=TRUE
+    if(SE){
+      
+      # Setting the control parameters
+      if(is.null(SE.control))
+        SE.control <- RPESE.control(estimator="ES")
+      
+      # Fix the method
+      method="historical"
+      portfolio_method="single"
+      invert=FALSE
+      if(SE.control$cleanOutliers=="locScaleRob")
+        clean="locScaleRob" else
+          clean="none"
+    }
 
     # Setup:
     #if(exists(modified)({if( modified == TRUE) { method="modified" }}
@@ -258,7 +282,7 @@ ETL <- CVaR <- ES <- function (R=NULL , p=0.95, ...,
         weights=t(rep(1/dim(R)[[2]], dim(R)[[2]]))
     }
     if(!is.null(R)){
-        R <- checkData(R, method="xts", ...)
+        R <- checkData(R, method="xts")
         columns=colnames(R)
         if (!is.null(weights) & portfolio_method != "single") {
             if ( length(weights) != ncol(R)) {
@@ -287,6 +311,28 @@ ETL <- CVaR <- ES <- function (R=NULL , p=0.95, ...,
         }
     }
     
+    if(isTRUE(SE)){
+      if(!requireNamespace("RPESE", quietly = TRUE)){
+        stop("Package \"pkg\" needed for standard errors computation. Please install it.",
+             call. = FALSE)
+      }
+      
+      # Computation of SE (optional)
+      ses=list()
+      # For each of the method specified in se.method, compute the standard error
+      for(mymethod in SE.control$se.method){
+        ses[[mymethod]]=RPESE::EstimatorSE(R, estimator.fun = "ES", se.method = mymethod, 
+                                           cleanOutliers=SE.control$cleanOutliers,
+                                           fitting.method=SE.control$fitting.method,
+                                           freq.include=SE.control$freq.include,
+                                           freq.par=SE.control$freq.par,
+                                           a=SE.control$a, b=SE.control$b,
+                                           p=p, # Additional parameter
+                                           ...)
+      }
+      ses <- t(data.frame(ses))
+    }
+    
     switch(portfolio_method,
         single = {
             if(is.null(weights)){
@@ -332,7 +378,10 @@ ETL <- CVaR <- ES <- function (R=NULL , p=0.95, ...,
             } # end reasonableness checks
             if(invert) rES <- -rES
             rownames(rES) <- "ES"
-            return(rES)
+            
+            if(SE) # Check if SE computation
+              return(rbind(rES, ses)) else
+                return(rES)
 
         }, # end single portfolio switch
         component = {
@@ -361,7 +410,7 @@ ETL <- CVaR <- ES <- function (R=NULL , p=0.95, ...,
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2020 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
