@@ -33,9 +33,11 @@
 ###keywords ts multivariate distribution models
 #' @examples
 #' 
+#' \dontrun{ # CRAN doesn't like how long this takes (>5 secs)
 #' data(managers)
 #' head(Return.clean(managers[,1:4]),n=20)
 #' chart.BarVaR(managers[,1,drop=FALSE], show.clean=TRUE, clean="boudt", lwd=2, methods="ModifiedVaR")
+#' }
 #' 
 #' @export
 Return.clean <-
@@ -76,7 +78,10 @@ function(R, method = c("none","boudt","geltner"), alpha=.01, ...)
             },
 	    geltner = {
 		R.clean = Return.Geltner(R[,column])
-	    }
+	    },
+		locScaleRob = {
+		  R.clean = Return.locScaleRob(R[,column], ...)
+		}
         )
 
         if(column == 1) {
@@ -264,7 +269,7 @@ function(R, alpha=.01 , trim=1e-3)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2020 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
